@@ -17,11 +17,11 @@ App::GitHooks::Hook - Base class for all git hook handlers.
 
 =head1 VERSION
 
-Version 1.1.5
+Version 1.2.0
 
 =cut
 
-our $VERSION = '1.1.5';
+our $VERSION = '1.2.0';
 
 
 =head1 METHODS
@@ -58,7 +58,11 @@ sub run
 	my $has_errors = 0;
 	foreach my $plugin ( @$plugins )
 	{
+		# Since Perl doesn't allow dashes in method names but git hook names have
+		# dashes, we need to make sure we convert dashes to underscores when
+		# generating the method name to run.
 		my $method = 'run_' . $app->get_hook_name();
+		$method =~ s/-/_/g;
 
 		my $return_code = $plugin->$method(
 			app => $app,
@@ -120,7 +124,7 @@ C<< <aubertg at cpan.org> >>.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2013-2014 Guillaume Aubert.
+Copyright 2013-2015 Guillaume Aubert.
 
 This program is free software: you can redistribute it and/or modify it under
 the terms of the GNU General Public License version 3 as published by the Free
